/*------------------------------------------------------------------------

   Filename: NetQ.h

Description: InstallShield installation Script for NetQuestion

    Version: 1.0

     Author: Rodney Thomas, RTP
       Tool: InstallSHIELD3
       Date: 04/29/97

   Comments:

       This script contains the functions necessary for installing NetQuestion.

IBM Confidential

OCO Source Materials

The source code for this program is not published or otherwise
    divested of its trade secrets, irrespective of what has
    been deposited with the U.S. Copyright Office.
Copyright:  Licensed Materials - Property of IBM

        5639-A45 (C) Copyright IBM Corp. 1997, 2000
        All rights reserved.

        U.S. Government Users Restricted Rights -
        Use, duplication or disclosure restricted by
        GSA ADP Schedule Contract with IBM Corp.


CHANGE-ACTIVITY:

$MOD(select.rul),COMP(csnt_install),PROD(CSNT): module title

FLAG  REASON   RELEASE   DATE     ORIGIN   DESCRIPTORS
---- --------  --------- -------- ------   ---------------------------------------------------
NA                       04/29/97 rlt      Created.
                         07/03/97 xstein   Complete redesign to straightline the spaghetti code
NA                       99/01/13 hwa      update version numbers
NA                       99/01/14 hwa      remove ICS-Lite Folder Icon / add MWS Folder Icon
NA                       99/01/15 hwa      remove old ICS-Lite files (see NetQRemoveICSLFiles) 
---------------------------------------------------------------------------------------------*/

// Give the desired installation directory as the first parameter to the call of
// NetQInstall. If NetQuestion isn't already installed it will be installed to this
// directory.
//
// Use a or'ed combination of the components to be installed as the second parameter
// to the call of NetQInstall. If you want the installed services to be started
// automatically when the user logs in (started anyway if there is no login), use the
// or the autostart flag to the components desired, too.
//
// NetQInstall returns the error codes as listed below.
//
// Note: SBCS runtime will be always installed. Prerequisite components for other
// components will be installed automatically. Components already installed will
// be updated if necessary.
//
// NetQDiskSpaceRequired returns the amount of disk space required for the components
// given. Note that this function does not calculate the disk space required for
// prerequisite components that are not given. It does, however, set the disk space
// required for components already installed to zero.
//
// NetQGetInstallDir returns FALSE if NetQuestion is not yet installed. If NetQuestion
// is already installed this function returns TRUE. In this case the installation path
// is returned to the string parameter given.
//
// If you have to rename the archive file IMNNQ.Z for any reason you will have to edit
// the definition below to reflect the change.

// component bitmap

#ifndef IS5
#define IS3 0x1
#endif

#define NETQ_INSTALL_SBCS       0x1  // install SBCS runtime
#define NETQ_INSTALL_ICSL       0x2  // install ICS Lite
#define NETQ_INSTALL_DBCS       0x4  // install DBCS runtime
#define NETQ_INSTALL_SBCSB      0x8  // install SBCS build time
#define NETQ_INSTALL_DBCSB      0x10 // install DBCS build time

// autostart select

#define NETQ_AUTOSTART          0x8000  // activate autostart

// install status codes

#define NETQ_IS_STARTED              0   // install started
#define NETQ_IS_COMPLETED            1   // install successfully completed

#define NETQ_IS_OTHER_ERROR          2   // some error occured during installation
#define NETQ_IS_OUT_OF_DISK_SPACE    3   // insufficient disk space available
#define NETQ_IS_OUT_OF_PATH_SPACE    4   // PATH variable too long
#define NETQ_IS_TARGET_IN_USE        401 // target path is already in use
#define NETQ_IS_DEFAULT_TGT_IN_USE   402 // default target path is already in use
#define NETQ_IS_KILL_PROCESSES       5   // kill processes failed
#define NETQ_IS_FILE_TRANSFER        6   // file transfer failed
#define NETQ_IS_SET_ENVIRONMENT      7   // set environment failed
#define NETQ_IS_CREATE_ENV_FILE_SBCS 71  // create env.bat file for SBCS failed
#define NETQ_IS_COPY_ENV_FILE_SBCS   711 // copy env.bat file for SBCS failed
#define NETQ_IS_ADDSTR_ENV_FILE_SBCS 712 // add string to env.bat file for SBCS failed
#define NETQ_IS_CREATE_ICSL_CNF_FILE 72  // create ICSL configuration file failed
#define NETQ_IS_RENAME_ICSL_TPL_FILE 721 // rename ICSL template file failed
#define NETQ_IS_READ_ICSL_CNF_FILE   722 // read ICSL configuration file failed
#define NETQ_IS_WRITE_ICSL_CNF_FILE  723 // write ICSL configuration file failed
#define NETQ_IS_CREATE_ENV_FILE_DBCS 73  // create env.bat file for DBCS failed
#define NETQ_IS_COPY_ENV_FILE_DBCS   731 // copy env.bat file for DBCS failed
#define NETQ_IS_ADDSTR_ENV_FILE_DBCS 732 // add string to env.bat file for DBCS failed
#define NETQ_IS_INTERNAL_ERROR       9   // InstallShield internal error

// return codes

#define NETQ_RC_INSTALLED           0   // successful install
#define NETQ_RC_OUT_OF_PATH_SPACE   1   // PATH variable too long
#define NETQ_RC_OTHER_ERROR         2   // some error occured during installation
#define NETQ_RC_OUT_OF_DISK_SPACE   3   // insufficient disk space available

// archive file

#define NETQ_ARCHIVE_FILE       "IMNNQ.Z"

// public prototypes
// ----------------------------------------------------------------------------------------
// PUBLIC PROTOTYPES FOR NETQUESTION INSTALL, YOU MAY CALL ANY OF THOSE FUNCTIONS!!!!!!!!!!
// ----------------------------------------------------------------------------------------

prototype NetQInstall( STRING, NUMBER );     // NetQInstall( InstallPath, Components );
prototype NetQDiskSpaceRequired( NUMBER );   // NetQDiskSpaceRequired( Components );
prototype NetQGetInstallDir( BYREF STRING ); // NetQGetInstallDir( InstallPath );

// ----------------------------------------------------------------------------------------
// PRIVATE DEFINITIONS FOR NETQUESTION INSTALL, DO NOT USE ANY OF THE VALUES!!!!!!!!!!!!!!
// ----------------------------------------------------------------------------------------

// total number of components

#define NETQ_MAX_COMPONENTS     5

// total number of customer components ( must be in 1<<(n-1) !!! )

#define NETQ_CUSTOMER_COMPONENTS    3

// version numbers of components

// RR + AS: 30.09.97
// The version numbering changes to have enough numbers for fixpacks
//#define NETQ_SBCS_VERSION     1102
//#define NETQ_ICSL_VERSION     1102
//#define NETQ_DBCS_VERSION     1102

// digits from left to right (rvvmmfff)
//      one digit release, two digits version, two digits modification, three digits fix
#define NETQ_SBCS_VERSION       10203006
#define NETQ_ICSL_VERSION       20001001
#define NETQ_DBCS_VERSION       10201003


#define NETQ_SBCSB_VERSION      NETQ_SBCS_VERSION   // do not modify
#define NETQ_DBCSB_VERSION      NETQ_DBCS_VERSION   // do not modify

// component prerequisites bitmap

#define NETQ_PREREQ_SBCS        0x0
#define NETQ_PREREQ_ICSL        0x1
#define NETQ_PREREQ_DBCS        0x1
#define NETQ_PREREQ_SBCSB       0x1
#define NETQ_PREREQ_DBCSB       0xD
#define NETQ_PREREQ_DEFAULT     0x1


// overall installation status flag registry key

#define NETQ_REG_INSTALLSTATUS      "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\InstallStatus"

// component installation flag registry keys

#define NETQ_REG_SBCS_INSTALLED     "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\VersionNumber\\Version"
#define NETQ_REG_ICSL_INSTALLED     "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\Internet Connection Server Lite\\Installed?"
#define NETQ_REG_DBCS_INSTALLED     "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\DBCS\\Installed?"
#define NETQ_REG_SBCSB_INSTALLED    "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\Build\\SBCS?"
#define NETQ_REG_DBCSB_INSTALLED    "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\Build\\DBCS?"

// component version registry keys

#define NETQ_REG_SBCS_VERSION       "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\VersionNumber\\Version"
#define NETQ_REG_ICSL_VERSION       "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\Internet Connection Server Lite\\Version"
#define NETQ_REG_DBCS_VERSION       "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\DBCS\\Version"
#define NETQ_REG_SBCSB_VERSION      NETQ_REG_SBCS_VERSION   // do not modify
#define NETQ_REG_DBCSB_VERSION      NETQ_REG_DBCS_VERSION   // do not modify

// component package directories in archive file

#ifdef IS3
#define NETQ_PACKAGE_SBCS       "NETQ\\*.*"
#define NETQ_PACKAGE_ICSL_95    "ICSLITE\\95\\*.*"
#define NETQ_PACKAGE_ICSL_NT    "ICSLITE\\NT\\*.*"
#define NETQ_PACKAGE_DBCS       "DBCS\\*.*"
#define NETQ_PACKAGE_SBCSB      "SBCSB\\*.*"
#define NETQ_PACKAGE_DBCSB      "BDBCS\\*.*"
#define NETQ_REPAIR_SET         "NETQR"
#else
#define NETQ_PACKAGE_SBCS       "SBCS"
#define NETQ_PACKAGE_ICSL_95    "ICSLITE95"
#define NETQ_PACKAGE_ICSL_NT    "ICSLITENT"
#define NETQ_PACKAGE_DBCS       "DBCS"
#define NETQ_PACKAGE_SBCSB      "SBCSB"
#define NETQ_PACKAGE_DBCSB      "DBCSB"
#define NETQ_REPAIR_SET         "REPAIR"
#endif

// autostart keys and data

#define NETQ_REG_SYS_RUN            "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run"
#define NETQ_REG_SYS_RUN_SBCS       "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run\\IMNNQ"
#define NETQ_REG_SYS_RUN_ICSL       "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run\\IMNNQ ICS LITE"
#define NETQ_REG_SYS_RUN_MWS        "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run\\IMNNQ Mini Web Server"
#define NETQ_REG_SYS_RUN_NWS        "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run\\IMNNQ NetQ Web Server"
#define NETQ_REG_SYS_RUN_DBCS       "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run\\IMNNQ DBCS"
#define NETQ_REG_SYS_RUN_SBCSB      NETQ_REG_SYS_RUN_SBCS   // do not modify
#define NETQ_REG_SYS_RUN_DBCSB      NETQ_REG_SYS_RUN_DBCS   // do not modify

#define NETQ_REG_CMD_RUN_SBCS       "nqdetach.exe imnss.exe start server"
#define NETQ_REG_CMD_RUN_ICSL       "nqdetach.exe httpdl.exe -r %s\\httpd.cnf"
#define NETQ_REG_CMD_RUN_MWS        "nqdetach.exe httpdl.exe -r %s\\httpd.cnf"
#define NETQ_REG_CMD_RUN_NWS        "nqdetach.exe httpdl.exe -r %s\\httpd.cnf"
#define NETQ_REG_CMD_RUN_DBCS       "nqdetach.exe imqss.exe -start dbcshelp"
#define NETQ_REG_CMD_RUN_SBCSB      NETQ_REG_CMD_RUN_SBCS   // do not modify
#define NETQ_REG_CMD_RUN_DBCSB      NETQ_REG_CMD_RUN_DBCS   // do not modify

// optional files

#define NETQ_OPT_BATCH          "\\IMNNQ\\INITIMN.BAT"
#define NETQ_OPT_EXE            "\\IMNNQ\\INITIMN.EXE"
#define NETQ_OPT_DIR            "\\IMNNQ"
#define NETQ_OPT_EXEFILE        "INITIMN.EXE"
#define NETQ_OPT_FILE           "INITIMN.BAT"
#define NETQ_OPT_PIF            "INITIMN.PIF"
#define NETQ_OPT_ERRFILE        "IMNNQ.ERR"
#define NETQ_OPT_SIZEFILE       "IMNNQ.SIZ"

// uninstall files and parameters

#define NETQ_UNINSTALL_EXE      "UNINSTNQ.EXE"
#define NETQ_UNINSTALL_DLL      "UNINSTNQ.DLL"
#define NETQ_UNINSTALL_FILES    "NETQ\\UNINSTNQ.*"
#define NETQ_TERMINATE_CMD      "-TerminateNetQuestion"

// environment

#define NETQ_REG_SYSTEM_PATH    "\\SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment\\Path"
#define NETQ_REG_VAR_1          "\\SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment\\IMNINSTSRV"
#define NETQ_REG_VAR_2          "\\SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment\\IMNINST"
#define NETQ_REG_VAR_3          "\\SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment\\IMQCONFIGSRV"
#define NETQ_REG_VAR_4          "\\SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment\\IMQCONFIGCL"
#define NETQ_SYS_VAR_NAME_1     "IMNINSTSRV"
#define NETQ_SYS_VAR_NAME_2     "IMNINST"
#define NETQ_SYS_VAR_VALUE_2    "help"
#define NETQ_SYS_VAR_NAME_3     "IMQCONFIGSRV"
#define NETQ_SYS_VAR_VALUE_3    "\\instance"
#define NETQ_SYS_VAR_NAME_4     "IMQCONFIGCL"
#define NETQ_SYS_VAR_VALUE_4    "\\instance\\DBCSHELP"
#define NETQ_SBCS_ENV_FILE      "IMNENV.BAT"
#define NETQ_DBCS_ENV_FILE      "IMQENV.BAT"

// ICS Lite

#define NETQ_ICSL_PORT          "49213"
#define NETQ_ICSL_CONF_FILE     "httpd.cnf"
#define NETQ_ICSL_TPL_FILE      "httpdcnf.tpl"
#define NETQ_ICSL_BACKUP_FILE   "httpd.000"


// miscellaneous definitions

#define NETQ_INSTALL_PATH       "\\SOFTWARE\\IBM\\NetQuestion\\CurrentVersion\\Installation Directory\\Directory"
#define NETQ_FILE_SET           "NETQ"
#define NETQ_DBCS_INI_FILE      "imqsrv.ini"
#define NETQ_DBCS_CONFIG        "\\config.exe"
#define NETQ_REG_CMD_TERM_SBCS  "nqdetach.exe imnss.exe stop server"
#define NETQ_REG_CMD_TERM_DBCS  "nqdetach.exe imqss.exe -stop dbcshelp"
#define NETQ_QUERY_SIZE         "?"
#ifdef IS3
#define NETQ_TARGET_STR         "NETQW"
#else
#define NETQ_TARGET_STR         ""
#endif


// operating system

#define NETQ_OS_UNDEFINED            0   // undefined
#define NETQ_OS_WINDOWS_95           1   // Windows 95
#define NETQ_OS_WINDOWS_98           2   // Windows 98
#define NETQ_OS_WINDOWS_NT           3   // Windows NT
#define NETQ_OS_WINDOWS_2000         4   // Windows 2000

// operating system specific default installation directory

#define NETQ_DEFAULT_INSTALL_DIR_95   "\\imnnq_95"
#define NETQ_DEFAULT_INSTALL_DIR_98   "\\imnnq_98"
#define NETQ_DEFAULT_INSTALL_DIR_NT   "\\imnnq_nt"
#define NETQ_DEFAULT_INSTALL_DIR_2000 "\\imnnq_2000"


// build time definitions

#define NETQ_BT_FOLDER          "NetQuestion Help Search Service"
#define NETQ_BT_SBCS_START      "Start SBCS Server"
#define NETQ_BT_SBCS_STOP       "Stop SBCS Server"
#define NETQ_BT_DBCS_START      "Start DBCS Server"
#define NETQ_BT_DBCS_STOP       "Stop DBCS Server"
#define NETQ_BT_ICSL_START      "Start ICS Lite Server"
#define NETQ_BT_MWS_START       "Start Mini Web Server"
#define NETQ_BT_NWS_START       "Start NetQ Web Server"
#define NETQ_BT_UNINSTALL       "Uninstall NetQuestion"
#define NETQ_BT_REG_PATH_95      "\\.Default\\Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders\\Programs"
#define NETQ_BT_REG_PATH_NT      "\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders\\Common Programs"

// ----------------------------------------------------------------------------------------
// PRIVATE PROTOTYPES FOR NETQUESTION INSTALL, DO NOT CALL ANY OF THE FUNCTIONS!!!!!!!!!!!!
// ----------------------------------------------------------------------------------------

prototype NetQVerifyTarget( BYREF STRING );
prototype NetQGetMaxPathLength( BYREF NUMBER );
prototype NetQRemoveICSLFiles( STRING );
prototype NetQCheckPathLength( STRING );
prototype NetQSetEnvironment( STRING, NUMBER );
prototype NetQSetRegistry( STRING, NUMBER );
prototype NetQDiskSpaceAvailable( STRING, NUMBER );
prototype NetQTransferFiles( STRING, NUMBER );
prototype NetQSelectItems( NUMBER );
prototype NetQKillProcesses();
prototype NetQAssertRepair();
prototype NetQComponentValues( NUMBER, BYREF NUMBER, BYREF NUMBER, BYREF NUMBER, BYREF NUMBER );
prototype NetQComponentData( NUMBER, BYREF NUMBER, BYREF STRING, BYREF NUMBER, BYREF STRING, BYREF STRING, BYREF STRING, BYREF STRING );
prototype NetQRegGetNum( STRING, NUMBER );
prototype NetQRegGetUsersStr( STRING, BYREF STRING, STRING );
prototype NetQRegGetStr( STRING, BYREF STRING, STRING );
prototype NetQRegSetNum( STRING, NUMBER );
prototype NetQRegSetStr( STRING, STRING );
prototype NetQGetPlatform();
prototype NetQGetOS();
prototype NetQGetDefaultInstDir( BYREF STRING );
prototype NetQCallBatch( STRING );
prototype NetQCreateErrFile( NUMBER );
prototype NetQCreateSizeFile( NUMBER );
prototype NetQGetTempDir( BYREF STRING );
prototype NetQBatchAddString( STRING );
prototype NetQCreateIcons( STRING );
